Bio2BEL HMDD |docs|
===================
Converts the Human microRNA Disease Database to BEL

Citation
--------
Li Y, Qiu C, Tu J, et al. HMDD v2.0: a database for experimentally supported human microRNA and disease associations. Nucleic Acids Research. 2014;42(Database issue):D1070-D1074. doi:10.1093/nar/gkt1023.

Abstract
--------
HMDD (the Human microRNA Disease Database) is a database that curated experiment-supported evidence for human microRNA (miRNA) and disease associations. miRNAs are one class of important regulatory RNAs, which mainly repress gene express at the post-transcriptional level. Increasing reports have shown that miRNAs play important roles in various critical biological processes. For their importance, the dysfunctions of miRNAs are associated with a broad spectrum of diseases. The first version of HMDD was built on December 2007. Each entry in HMDD v1.0 has four items for annotation; they are miRNA name, disease name, the reference PubMed ID, and the evidence supporting the miRNA-association from the original paper. During the past five years, we updated HMDD for more than 30 times. HMDD v2.0 presents more detailed and comprehensive annotations to the human miRNA-disease association data, including miRNA-disease association data from the evidence of genetics, epigenetics, circulating miRNAs, and miRNA-target interactions. In addition, a “submission” function was implemented in the version 2.

Links
-----
- Database: http://www.cuilab.cn/hmdd
- Data: http://www.cuilab.cn/files/images/hmdd2/alldata.txt

.. |docs| image:: http://readthedocs.org/projects/bio2bel-hmdd/badge/?version=latest
    :target: http://bio2bel.readthedocs.io/projects/hmdd/en/latest/?badge=latest
    :alt: Documentation Status
